@@ -1,9 +1,7 @@
 package App::DuckPAN;
-BEGIN {
-  $App::DuckPAN::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.165';
+
 use feature 'state';
 
 use Moo;
@@ -571,7 +569,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 DuckPAN
 
