@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Check;
-BEGIN {
-  $App::DuckPAN::Cmd::Check::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command for checking the requirements
-$App::DuckPAN::Cmd::Check::VERSION = '0.165';
+$App::DuckPAN::Cmd::Check::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -30,7 +28,7 @@ App::DuckPAN::Cmd::Check - Command for checking the requirements
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
