@@ -1,11 +1,11 @@
 package App::DuckPAN::Cmd::Help;
-BEGIN {
-  $App::DuckPAN::Cmd::Help::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Launch help page
-$App::DuckPAN::Cmd::Help::VERSION = '0.165';
+$App::DuckPAN::Cmd::Help::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
+
+use MooX::Options protect_argv => 0;
 use Pod::Usage qw(pod2usage);
 
 sub run {
@@ -28,7 +28,7 @@ App::DuckPAN::Cmd::Help - Launch help page
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
