@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Install;
-BEGIN {
-  $App::DuckPAN::Cmd::Install::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Install the distribution in current directory
-$App::DuckPAN::Cmd::Install::VERSION = '0.165';
+$App::DuckPAN::Cmd::Install::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -16,7 +14,7 @@ sub run {
 		$self->app->emit_info("Found a dist.ini, suggesting a Dist::Zilla distribution");
 
 		$self->app->perl->cpanminus_install_error
-			if (system("dzil install --install-command 'cpanm .'"));
+			if (system("dzil install --install-command 'cpanm .' @args"));
 		$self->app->emit_info("Everything fine!");
 	}
 
@@ -34,7 +32,7 @@ App::DuckPAN::Cmd::Install - Install the distribution in current directory
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
