@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Installdeps;
-BEGIN {
-  $App::DuckPAN::Cmd::Installdeps::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Regular way to install requirements with tests
-$App::DuckPAN::Cmd::Installdeps::VERSION = '0.165';
+$App::DuckPAN::Cmd::Installdeps::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -35,7 +33,7 @@ App::DuckPAN::Cmd::Installdeps - Regular way to install requirements with tests
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
