@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::New;
-BEGIN {
-  $App::DuckPAN::Cmd::New::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Take a name as input and generates a new, named Goodie or Spice instant answer skeleton
-$App::DuckPAN::Cmd::New::VERSION = '0.165';
+$App::DuckPAN::Cmd::New::VERSION = '0.166';
 # For Goodies:
 # 	- <name>.pm file is created in lib/DDG/Goodie
 #
@@ -15,6 +13,8 @@ $App::DuckPAN::Cmd::New::VERSION = '0.165';
 
 use Moo;
 with qw( App::DuckPAN::Cmd );
+
+use MooX::Options protect_argv => 0;
 use Text::Xslate qw(mark_raw);
 use Path::Tiny;
 
@@ -93,7 +93,7 @@ App::DuckPAN::Cmd::New - Take a name as input and generates a new, named Goodie
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
