@@ -1,14 +1,11 @@
 package App::DuckPAN::Cmd::Publisher;
-BEGIN {
-  $App::DuckPAN::Cmd::Publisher::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Starting up the publisher test webserver
-$App::DuckPAN::Cmd::Publisher::VERSION = '0.165';
+$App::DuckPAN::Cmd::Publisher::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
 use MooX::Options protect_argv => 0;
-
 use Path::Tiny;
 use Plack::Handler::Starman;
 
@@ -82,7 +79,7 @@ App::DuckPAN::Cmd::Publisher - Starting up the publisher test webserver
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
