@@ -1,21 +1,28 @@
 package App::DuckPAN::Cmd::Query;
-BEGIN {
-  $App::DuckPAN::Cmd::Query::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command line tool for testing queries and see triggered instant answers
-$App::DuckPAN::Cmd::Query::VERSION = '0.165';
+$App::DuckPAN::Cmd::Query::VERSION = '0.166';
 use MooX;
+with qw( App::DuckPAN::Cmd App::DuckPAN::Restart );
+
 use MooX::Options protect_argv => 0;
-with qw( App::DuckPAN::Cmd );
+
+# Entry point into app
 
 sub run {
-	my ($self, @args) = @_;
+    my ($self, @args) = @_;
 
-	$self->app->check_requirements;    # Will exit if missing
-	my @blocks = @{$self->app->ddg->get_blocks_from_current_dir(@args)};
+    exit $self->run_restarter(\@args);
+}
 
-	require App::DuckPAN::Query;
-	exit App::DuckPAN::Query->run($self->app, @blocks);
+sub _run_app {
+    my ($self, $args) = @_;
+
+    $self->app->check_requirements;    # Will exit if missing
+    my @blocks = @{$self->app->ddg->get_blocks_from_current_dir(@$args)};
+
+    require App::DuckPAN::Query;
+    App::DuckPAN::Query->run($self->app, \@blocks);
 }
 
 1;
@@ -30,7 +37,7 @@ App::DuckPAN::Cmd::Query - Command line tool for testing queries and see trigger
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
