@@ -1,13 +1,12 @@
 package App::DuckPAN::Cmd::Release;
-BEGIN {
-  $App::DuckPAN::Cmd::Release::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Release the distribution of the current directory
-$App::DuckPAN::Cmd::Release::VERSION = '0.165';
+$App::DuckPAN::Cmd::Release::VERSION = '0.166';
 use MooX;
-use MooX::Options protect_argv => 0;
 with qw( App::DuckPAN::Cmd );
 
+use MooX::Options protect_argv => 0;
+
 sub run {
     my ( $self ) = @_;
 
@@ -30,7 +29,7 @@ App::DuckPAN::Cmd::Release - Release the distribution of the current directory
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
