@@ -1,13 +1,11 @@
 package App::DuckPAN::Cmd::Roadrunner;
-BEGIN {
-  $App::DuckPAN::Cmd::Roadrunner::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Install requirements as fast as possible
-$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.165';
+$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
-use MooX::Options;
+use MooX::Options protect_argv => 0;
 use Time::HiRes qw( usleep );
 
 sub run {
@@ -46,7 +44,7 @@ App::DuckPAN::Cmd::Roadrunner - Install requirements as fast as possible
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
