@@ -1,11 +1,9 @@
 package App::DuckPAN::Cmd::Server;
-BEGIN {
-  $App::DuckPAN::Cmd::Server::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Starting up the web server to test instant answers
-$App::DuckPAN::Cmd::Server::VERSION = '0.165';
+$App::DuckPAN::Cmd::Server::VERSION = '0.166';
 use Moo;
-with qw( App::DuckPAN::Cmd );
+with qw( App::DuckPAN::Cmd App::DuckPAN::Restart );
 
 use MooX::Options protect_argv => 0;
 use Plack::Runner;
@@ -16,7 +14,6 @@ use LWP::Simple;
 use HTML::TreeBuilder;
 use Config::INI;
 use Data::Printer;
-use Data::Dumper;
 use Term::ProgressBar;
 
 option port => (
@@ -34,6 +31,7 @@ has page_info => (
     builder => '_build_page_info',
     lazy=> 1,
 );
+
 sub _build_page_info {
     my $self       = shift;
     my $cache_path = $self->asset_cache_path;
@@ -94,15 +92,24 @@ sub _build_asset_cache_path {
     return $asset_path;
 }
 
+# Entry point into app
 sub run {
     my ($self, @args) = @_;
 
+    $self->run_restarter(\@args);
+}
+
+# Starts the Plack server on the designated port.  Will be launched in a child
+# process since it blocks. Will be killed by user ctrl-c or parent explicitly
+# kill'ing it.
+sub _run_app {
+    my ($self, $args) = @_;
+
     my $cache_path = $self->app->cfg->cache_path;
 
     $self->app->check_requirements; # Ensure eveything is up do date, or exit.
 
-
-    my @blocks = @{$self->app->ddg->get_blocks_from_current_dir(@args)};
+    my @blocks = @{$self->app->ddg->get_blocks_from_current_dir(@$args)};
 
     $self->app->emit_debug("Hostname is: http://" . $self->hostname);
     $self->app->emit_info("Checking asset cache...");
@@ -427,7 +434,7 @@ App::DuckPAN::Cmd::Server - Starting up the web server to test instant answers
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
