@@ -1,13 +1,11 @@
 package App::DuckPAN::Cmd::Setup;
-BEGIN {
-  $App::DuckPAN::Cmd::Setup::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Setting up your duck.co Account on your duckpan client
-$App::DuckPAN::Cmd::Setup::VERSION = '0.165';
+$App::DuckPAN::Cmd::Setup::VERSION = '0.166';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
-use MooX::Options;
+use MooX::Options protect_argv => 0;
 use Email::Valid;
 
 option user => (
@@ -179,7 +177,7 @@ App::DuckPAN::Cmd::Setup - Setting up your duck.co Account on your duckpan clien
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
