@@ -1,13 +1,12 @@
 package App::DuckPAN::Cmd::Test;
-BEGIN {
-  $App::DuckPAN::Cmd::Test::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command for running the tests of this library
-$App::DuckPAN::Cmd::Test::VERSION = '0.165';
+$App::DuckPAN::Cmd::Test::VERSION = '0.166';
 use MooX;
-use MooX::Options protect_argv => 0;
 with qw( App::DuckPAN::Cmd );
 
+use MooX::Options protect_argv => 0;
+
 sub run {
     my ( $self ) = @_;
 
@@ -36,7 +35,7 @@ App::DuckPAN::Cmd::Test - Command for running the tests of this library
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
