@@ -1,9 +1,7 @@
 package App::DuckPAN::Perl;
-BEGIN {
-  $App::DuckPAN::Perl::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Perl related functionality for duckpan
-$App::DuckPAN::Perl::VERSION = '0.165';
+$App::DuckPAN::Perl::VERSION = '0.166';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
@@ -184,7 +182,7 @@ App::DuckPAN::Perl - Perl related functionality for duckpan
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
