@@ -1,9 +1,7 @@
 package App::DuckPAN::Web;
-BEGIN {
-  $App::DuckPAN::Web::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.165';
+$App::DuckPAN::Web::VERSION = '0.166';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -35,7 +33,6 @@ has _our_hostname => ( is => 'rw' );
 has _share_dir_hash => ( is => 'rw' );
 has _path_hash => ( is => 'rw' );
 has _rewrite_hash => ( is => 'rw' );
-has _query => ( is => 'rw' );
 
 has ua => (
 	is => 'ro',
@@ -77,7 +74,6 @@ sub run_psgi {
 }
 
 my $has_common_js = 0;
-my $error;
 sub request {
 	my ( $self, $request ) = @_;
 	my $hostname = $self->server_hostname;
@@ -88,8 +84,7 @@ sub request {
 
 	if ($request->request_uri eq "/"){
 		$response->content_type("text/html");
-		$body = $self->page_root unless $error;
-		$body = $self->_inject_error() and $error = "" if $error;
+		$body = $self->page_root;
 	} elsif (@path_parts && $path_parts[0] eq 'share') {
 		my $filename = pop @path_parts;
 		my $share_dir = join('/',@path_parts);
@@ -173,8 +168,8 @@ sub request {
 						$response->content_type($res->content_type);
 					} else {
 						p($res->status_line, color => { string => 'red' });
-						$error = encode_entities($res->status_line);
-						$body = "window.location.replace('http://" . $self->_our_hostname . "/')";
+						my $errormsg = (pop @{[split'::', $spice_class]}). ": ".$res->status_line;
+						$body = '$("div.content-wrap").append("<div class=\"msg msg--warning\">'. $errormsg .'</div>");';
 					}
 				}
 			}
@@ -198,7 +193,6 @@ sub request {
 		my $query = $request->param('q');
 		$query =~ s/^\s+|\s+$//g; # strip leading & trailing whitespace
 		Encode::_utf8_on($query);
-		$self->_query($query);
 		my $ddg_request = DDG::Request->new(
 			query_raw => $query,
 			location => test_location_by_env(),
@@ -231,9 +225,18 @@ sub request {
 
 		# Check for no results
 		if (!scalar(@results)) {
-			$error = "Sorry, no hit for your instant answer";
+			my $error = "Sorry, no hit for your instant answer";
+                        $root = HTML::TreeBuilder->new;
+                        $root->parse($self->page_root);
+			my $text_field = $root->look_down(
+				"name", "q"
+			);
+			$text_field->attr( value => $query );
+			$root->find_by_tag_name('body')->push_content(
+				HTML::TreeBuilder->new_from_content("<script type=\"text/javascript\">seterr('$error')</script>")->guts
+			);
 			p($error, color => { string => 'red' });
-			$page = $self->_inject_error();
+			$page = $root->as_HTML;
 		}
 
 		# Iterate over results,
@@ -370,11 +373,7 @@ sub request {
 			}
 		}
 		
-		if($error) {
-			$error = "";
-		} else {
-			$page = $root->as_HTML;
-		}
+		$page = $root->as_HTML;
 
 		$page =~ s/####DUCKDUCKHACK-CALL-NRJ####/$calls_nrj/g;
 		$page =~ s/####DUCKDUCKHACK-CALL-NRC####/$calls_nrc/g;
@@ -390,7 +389,7 @@ sub request {
 			$response->code($res->code);
 			$response->content_type($res->content_type);
 		} else {
-			warn $res->status_line, "\n";
+                        p($res->status_line, color => { string => 'red' });
 			$body = "";
 		}
 	}
@@ -398,20 +397,7 @@ sub request {
 	$response->body($body);
 	return $response;
 }
-sub _inject_error {
-	my $self = shift;
-	my $query = $self->_query;
-	my $root = HTML::TreeBuilder->new;
-	$root->parse($self->page_root);
-	my $text_field = $root->look_down(
-		"name", "q"
-	);
-	$text_field->attr( value => $query );
-	$root->find_by_tag_name('body')->push_content(
-		HTML::TreeBuilder->new_from_content("<script type=\"text/javascript\">seterr('$error')</script>")->guts
-	);
-	return $root->as_HTML;
-}
+
 1;
 
 __END__
@@ -424,7 +410,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 AUTHOR
 
